.. sceptre documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

..  _index:

Sceptre
=======

Contents:

.. toctree::
   :maxdepth: 1

   introduction
   installation
   get_started
   terminology
   command_line
   python_module
   environment_config
   stack_config
   templates
   advanced_patterns
   faq
   contributing
   authors
   history

Indices and tables
==================

* `Sceptre API <sceptre.html>`_
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
